@@ -9,10 +9,15 @@ from marshmallow_annotations.ext.attrs import AttrsSchema
 @attr.s(auto_attribs=True, kw_only=True)
 class LineageItem:
     key: str  # down/upstream table/col/task key
+    name: Optional[str] = ''  # name for dashboards
     level: int  # upstream/downstream distance from current resource
+    type: str  # indicate resouce type
+    group_name: Optional[str] = ''  # group name for dashboards
     description: Optional[str]
     badges: Optional[List[Badge]] = None
     usage: Optional[int] = None  # statistic to sort lineage items by
+    upstream_entities: Optional[List[str]] = []  # list of upstream table/col/task keys
+    downstream_entities: Optional[List[str]] = []  # list of downstream table/col/task keys
 
 
 class LineageItemSchema(AttrsSchema):
@@ -33,4 +38,4 @@ class Lineage:
 class LineageSchema(AttrsSchema):
     class Meta:
         target = Lineage
-        register_as_scheme = True
\ No newline at end of file
+        register_as_scheme = True
